==> flutter_tapjoy-1.2.2%2B2.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_tapjoy/flutter_tapjoy.dart';

void main() async {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  void initTapjoy() {
    Tapjoy.setDebugEnabled(isDebug: true);
    Tapjoy.setUserConsent(consent: '1');
    Tapjoy.connect(listener,apiToken:'apiToken');
  }

  @override
  void initState() {
    initTapjoy();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Column(
          children: <Widget>[
            RaisedButton(
              child: Text('show Ad'),
              onPressed: () async {
                if (await Tapjoy.onContentReady()) {
                  Tapjoy.showContent();
                }
              },
            ),
          ],
        ),
      ),
    );
  }
}

listener(TapjoyPlacementListener event, int reward, String error) {
  if (event == TapjoyPlacementListener.onConnectSuccess) {
    Tapjoy.getPlacement(placementName: 'placementName')
                    .then((_) => Tapjoy.requestContent());
    print('connect success');
  } else if (event == TapjoyPlacementListener.onContentFailure) {
    print('Tapjoy Placement ERROR: $error');
  } else if (event == TapjoyPlacementListener.onReward) {
    print('Tapjoy SDK $reward');
  } else if (event == TapjoyPlacementListener.onContentDismiss) {
    print('dismissed');
  } else if (event == TapjoyPlacementListener.onVideoStarted) {
    print('on video started');
  } else if (event == TapjoyPlacementListener.onVideoComplete) {
    print('on video completed');
  }
}

==> flutter_tapjoy-1.2.3%2B2.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_tapjoy/flutter_tapjoy.dart';

void main() async {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {

  void initTapjoy() {
    Tapjoy.setDebugEnabled(isDebug: true);
    Tapjoy.setUserConsent(consent: '1');
    Tapjoy.connect(listener,apiToken:'api_token');
  }

  @override
  void initState() {
    initTapjoy();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Column(
          children: <Widget>[
            RaisedButton(
              child: Text('Show Ad'),
              onPressed: () async {
                if (await Tapjoy.isLoaded()) {            
                 Tapjoy.showContent();
                 }
              },
            ),
          ],
        ),
      ),
    );
  }
}

listener(TapjoyPlacementListener event, int reward, String error) {
  if (event == TapjoyPlacementListener.onConnectSuccess) {
    Tapjoy.getPlacement(placementName: 'placement_name');
    print('connect success');
  } else if(event == TapjoyPlacementListener.onRequestSuccess) {
    print('connect');
  } else if(event == TapjoyPlacementListener.onContentReady) {
    print('content is ready');
  }
  else if (event == TapjoyPlacementListener.onContentFailure) {
    print('Tapjoy Placement ERROR: $error');
  } else if (event == TapjoyPlacementListener.onReward) {
    print('Tapjoy SDK $reward');
  } else if (event == TapjoyPlacementListener.onContentDismiss) {
    print('dismissed');
  } else if (event == TapjoyPlacementListener.onVideoStarted) {
    print('on video started');
  } else if (event == TapjoyPlacementListener.onVideoComplete) {
    print('on video completed');
  }
}
